import { defineStore } from 'pinia';
import http from '@/jtools/request/index';
import { queryQuestion, getVersion, querySysConfig } from '@/jtools/api/question';
import storage from '@/jtools/storage';
let JSON_SPLIT_LENGTH = 10;

const question = defineStore({
  id: 'question',
  state: () => ({
    currentCartype: storage.get('carType') || '1001',
    currentCarName: storage.get('carName') || '小车C1/C2/C3',
    orderQuestion_subject1: [], //科目一顺序做题
    orderQuestion_subject4: [], //科目四顺序做题
    currentIndex_subject1: 0, //科目一索引 顺序做题
    currentIndex_subject4: 0, //科目四索引 顺序做题
    curSubject: storage.get('curSubject') || '1',
    loading_subject1: false,
    loading_subject4: false,
    version: storage.get('version') || ''
  }),

  actions: {
    resetStorage() {
      this.currentIndex_subject1 = 0;
      this.currentIndex_subject4 = 0;
      this.curSubject = 0;
      storage.remove('curSubject');
      storage.remove('wrongList_subject1');
      storage.remove('wrongList_subject4');
      storage.remove('rightList_subject1');
      storage.remove('rightList_subject4');
      // this.getAllQuestion()
    },
    getAllQuestion() {
      this.currentCartype = storage.get('carType') || '1001';
      getVersion(this.currentCartype).then(resp => {
        if (resp.code === '0000') {
          querySysConfig(this.currentCartype, 'QuestionBank').then(res => {
            const urlList = JSON.parse(res.data.configJson);
            const urlOne = urlList.find(item => item.subject == '1').url;
            const urlFour = urlList.find(item => item.subject == '4').url;
            if (this.version != resp.data) {
              this.version = resp.data;
              storage.set('version', resp.data);
              this.getOrderQuestion_sub1(true, urlOne);
              this.getOrderQuestion_sub4(true, urlFour);
            } else {
              this.getOrderQuestion_sub1(false, urlOne);
              this.getOrderQuestion_sub4(false, urlFour);
            }
          });
        }
      });
    },
    divideArray(array, numChunks) {
      var chunkSize = Math.ceil(array.length / numChunks);
      var dividedArray = [];
      for (var i = 0; i < array.length; i += chunkSize) {
        dividedArray.push(array.slice(i, i + chunkSize));
      }
      return dividedArray;
    },

    //改变当前科目
    changeSubject(val) {
      this.curSubject = val;
      storage.set('curSubject', val);
    },
    // 获取顺序做题科目1
    getOrderQuestion_sub1(isUpdate, url) {
      if (isUpdate) {
        this.loading_subject1 = true;
        this.loadAllQuestion(url, 1);
      } else {
        this.orderQuestion_subject1 = [];
        for (let i = 0; i < JSON_SPLIT_LENGTH; i++) {
          const arr = uni.getStorageSync(`question1Sub${i + 1}`) || [];
          this.orderQuestion_subject1 = [...this.orderQuestion_subject1, ...arr];
        }
        if (this.orderQuestion_subject1.length == 0) {
          this.loading_subject1 = true;
          this.loadAllQuestion(url, 1);
        }
      }
    },
    // 获取顺序做题科目4
    getOrderQuestion_sub4(isUpdate, url) {
      if (isUpdate) {
        this.loading_subject4 = true;
        this.loadAllQuestion(url, 4);
      } else {
        this.orderQuestion_subject4 = [];
        for (let i = 0; i < JSON_SPLIT_LENGTH; i++) {
          const arr = uni.getStorageSync(`question4Sub${i + 1}`) || [];
          this.orderQuestion_subject4 = [...this.orderQuestion_subject4, ...arr];
        }
        if (this.orderQuestion_subject4.length == 0) {
          this.loading_subject4 = true;
          this.loadAllQuestion(url, 4);
        }
      }
    },
    // 加载线上题目
    loadAllQuestion(url, course) {
      const that = this;
      uni.request({
        url: url,
        success(resp) {
          if (resp?.data) {
            try {
              for (let i = 0; i < JSON_SPLIT_LENGTH; i++) {
                storage.remove(`question${course}Sub${i + 1}`);
              }
              that[`orderQuestion_subject${course}`] = resp.data?.data || [];
              const diveList = that.divideArray(that[`orderQuestion_subject${course}`], JSON_SPLIT_LENGTH);
              that[`loading_subject${course}`] = false;
              for (let i = 0; i < JSON_SPLIT_LENGTH; i++) {
                uni.setStorageSync(`question${course}Sub${i + 1}`, diveList[i]);
              }
              const falseList = storage.get(`wrongList_subject${course}`) || [];
              const trueList = storage.get(`rightList_subject${course}`) || [];
              const falseArr = [];
              const rightArr = [];
              that[`orderQuestion_subject${course}`].forEach(item => {
                if (falseList.includes(item.questionId)) {
                  falseArr.push(item.questionId);
                }
                if (trueList.includes(item.questionId)) {
                  rightArr.push(item.questionId);
                }
              });
              storage.set(`wrongList_subject${course}`, falseArr);
              storage.set(`rightList_subject${course}`, rightArr);
            } catch (err) {
              console.log(err);
              uni.showToast({
                title: '题库下载异常，请稍后再试',
                icon: 'none'
              });
            }
          } else {
            uni.showToast({
              title: '加载题目失败，请稍后再试',
              icon: 'none'
            });
          }
        }
      });
    },
    //获取索引
    getCurrentIndex(index, val) {
      this[`currentIndex_subject${val}`] = index;
    }
  }
});

export default question;
